@@ -3,7 +3,7 @@ import json
 import os
 import random
 import string
-from typing import Union
+from typing import Union, Dict
 
 from PIL import Image as PIL_IMAGE
 from assertpy import assert_that
@@ -18,7 +18,7 @@ from deepdriver.sdk.interface import interface
 class Image(Media):
 
     def __init__(self, data: Union[str, PIL_IMAGE.Image], caption: str = None,
-                 boxes: Union[dict[str, BoundingBoxes], dict[str, dict]] = None) -> None:
+                 boxes: Union[Dict[str, BoundingBoxes], Dict[str, dict]] = None) -> None:
         super().__init__(log_type=LOG_TYPE_IMAGE)
 
         assert_that(data).is_not_none()
